@@ -20,4 +20,5 @@ B[0, 0] = B[-1, 0] = 0.5
 B[0, 1] = n - 1
 
 C = np.zeros((3, n))
-C[0, 0] = C[1, k] = C[2, -1] = 1
+C[0, :n//3] = C[1, n//3:2*n//3] = C[2, 2*n//3:] = 1
+C /= C.sum(axis=1)[:, np.newaxis]
